@@ -30,9 +30,12 @@ class TestSourceCode(unittest.TestCase):
                     stderr=subprocess.PIPE,
                     cwd=os.path.join(edgepath, subdir))
             except subprocess.CalledProcessError as ex:
-                output = ex.output.decode()
+                output = ex.stdout.decode()
+                output += '\n'
+                output += ex.stderr.decode()
                 raise AssertionError(
-                    'flake8 validation failed:\n{}'.format(output)) from None
+                    'flake8 validation failed: {}\n{}'.format(ex, output)
+                ) from None
 
     def test_mypy(self):
         edgepath = find_uvloop_root()
@@ -61,6 +64,9 @@ class TestSourceCode(unittest.TestCase):
                 cwd=edgepath
             )
         except subprocess.CalledProcessError as ex:
-            output = ex.output.decode()
+            output = ex.stdout.decode()
+            output += '\n'
+            output += ex.stderr.decode()
             raise AssertionError(
-                'mypy validation failed:\n{}'.format(output)) from None
+                'mypy validation failed: {}\n{}'.format(ex, output)
+            ) from None
