@@ -1,5 +1,6 @@
 #include <errno.h>
 #include <stddef.h>
+#include <signal.h>
 #include <sys/socket.h>
 #include <sys/un.h>
 #include "Python.h"
@@ -54,27 +55,7 @@ MakeUnixSockPyAddr(struct sockaddr_un *addr)
 }
 
 
-#if PY_VERSION_HEX < 0x03070000
-
-PyObject * Context_CopyCurrent(void) {
-    PyErr_SetString(PyExc_NotImplementedError,
-                    "\"contextvars\" support requires Python 3.7+");
-    return NULL;
-};
-
-int Context_Enter(PyObject *ctx) {
-    PyErr_SetString(PyExc_NotImplementedError,
-                    "\"contextvars\" support requires Python 3.7+");
-    return -1;
-}
-
-int Context_Exit(PyObject *ctx) {
-    PyErr_SetString(PyExc_NotImplementedError,
-                    "\"contextvars\" support requires Python 3.7+");
-    return -1;
-}
-
-#elif PY_VERSION_HEX < 0x03070100
+#if PY_VERSION_HEX < 0x03070100
 
 PyObject * Context_CopyCurrent(void) {
     return (PyObject *)PyContext_CopyCurrent();
@@ -104,25 +85,21 @@ int Context_Exit(PyObject *ctx) {
 
 #endif
 
+/* inlined from cpython/Modules/signalmodule.c
+ * https://github.com/python/cpython/blob/v3.13.0a6/Modules/signalmodule.c#L1931-L1951
+ * private _Py_RestoreSignals has been moved to CPython internals in Python 3.13
+ * https://github.com/python/cpython/pull/106400 */
 
-#if PY_VERSION_HEX < 0x03070000
-
-void PyOS_BeforeFork(void)
+void
+_Py_RestoreSignals(void)
 {
-    _PyImport_AcquireLock();
-}
-
-void PyOS_AfterFork_Parent(void)
-{
-    if (_PyImport_ReleaseLock() <= 0) {
-        Py_FatalError("failed releasing import lock after fork");
-    }
-}
-
-
-void PyOS_AfterFork_Child(void)
-{
-    PyOS_AfterFork();
-}
-
+#ifdef SIGPIPE
+    PyOS_setsig(SIGPIPE, SIG_DFL);
 #endif
+#ifdef SIGXFZ
+    PyOS_setsig(SIGXFZ, SIG_DFL);
+#endif
+#ifdef SIGXFSZ
+    PyOS_setsig(SIGXFSZ, SIG_DFL);
+#endif
+}
